@@ -178,7 +178,7 @@ main (int argc, char * argv[])
 
 	char *helper_policy = getenv("HELPER_POLICY");
 	if (helper_policy == NULL) {
-		printf("HELPER_POLICY enviroment variable is not set\n");
+		printf("HELPER_POLICY environment variable is not set\n");
 		exit(1);
 	}
 
